@@ -124,7 +124,7 @@ SEXP GPDPMIXMIS(SEXP Ymat, SEXP Otrend, SEXP Oseas, SEXP o_gp_mod, SEXP o_jitter
  
     // Set random number generator state
     RNGScope scope; /* Rcpp */
-    srand ( time(NULL) ); /* arma */
+    arma_rng::set_seed_random(); /* arma */
 
     // Initialize SAMPLED parameter values   
     /* cluster capture variables */
